define(["require", "exports", "../editInfoUtils/getTargetSizeByPercentage", "../editInfoUtils/editInfo"], function (require, exports, getTargetSizeByPercentage_1, editInfo_1) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    /**
     * Check if the image is already resized to the given percentage
     * @param image The image to check
     * @param percentage The percentage to check
     * @param maxError Maximum difference of pixels to still be considered the same size
     */
    function isResizedTo(image, percentage, maxError) {
        if (maxError === void 0) { maxError = 1; }
        var editInfo = (0, editInfo_1.getEditInfoFromImage)(image);
        //Image selection will sometimes return an image which is currently hidden and wrapped. Use HTML attributes as backup
        var visibleHeight = editInfo.heightPx || image.height;
        var visibleWidth = editInfo.widthPx || image.width;
        if (editInfo) {
            var _a = (0, getTargetSizeByPercentage_1.default)(editInfo, percentage), width = _a.width, height = _a.height;
            return (Math.abs(width - visibleWidth) < maxError && Math.abs(height - visibleHeight) < maxError);
        }
        return false;
    }
    exports.default = isResizedTo;
});
//# sourceMappingURL=isResizedTo.js.map