define(["require", "exports", "roosterjs-editor-dom", "./convertPastedContentFromWordOnline"], function (require, exports, roosterjs_editor_dom_1, convertPastedContentFromWordOnline_1) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var WAC_IDENTIFY_SELECTOR = 'ul[class^="BulletListStyle"]>.OutlineElement,ol[class^="NumberListStyle"]>.OutlineElement,span.WACImageContainer';
    var TABLE_TEMP_ELEMENTS_QUERY = [
        'TableInsertRowGapBlank',
        'TableColumnResizeHandle',
        'TableCellTopBorderHandle',
        'TableCellLeftBorderHandle',
        'TableHoverColumnHandle',
        'TableHoverRowHandle',
    ]
        .map(function (className) { return "." + className; })
        .join(',');
    /**
     * @internal
     * Convert pasted content from Office Online
     * Once it is known that the document is from WAC
     * We need to remove the display property and margin from all the list item
     * @param event The BeforePaste event
     */
    function convertPastedContentFromOfficeOnline(fragment, sanitizingOption) {
        fragment.querySelectorAll(WAC_IDENTIFY_SELECTOR).forEach(function (el) {
            var element = el;
            element.style.removeProperty('display');
            element.style.removeProperty('margin');
        });
        // call conversion function if the pasted content is from word online and
        // has list element in the pasted content.
        if ((0, convertPastedContentFromWordOnline_1.isWordOnlineWithList)(fragment)) {
            (0, convertPastedContentFromWordOnline_1.default)(fragment);
        }
        // Remove "border:none" for image to fix image resize behavior
        // We found a problem that when paste an image with "border:none" then the resize border will be
        // displayed incorrectly when resize it. So we need to drop this style
        (0, roosterjs_editor_dom_1.chainSanitizerCallback)(sanitizingOption.cssStyleCallbacks, 'border', function (value, element) { return element.tagName != 'IMG' || value != 'none'; });
        fragment
            .querySelectorAll(TABLE_TEMP_ELEMENTS_QUERY)
            .forEach(function (node) { var _a; return (_a = node.parentElement) === null || _a === void 0 ? void 0 : _a.removeChild(node); });
    }
    exports.default = convertPastedContentFromOfficeOnline;
});
//# sourceMappingURL=convertPastedContentFromOfficeOnline.js.map