import type { ContentEditFeatureSettings, EditorPlugin, GenericContentEditFeature, IEditor, PluginEvent } from 'roosterjs-editor-types';
/**
 * An editor plugin to handle content edit event.
 * The following cases are included:
 * 1. Auto increase/decrease indentation on Tab, Shift+tab
 * 2. Enter, Backspace on empty list item
 * 3. Enter, Backspace on empty blockquote line
 * 4. Auto bullet/numbering
 * 5. Auto link
 * 6. Tab in table
 * 7. Up/Down in table
 * 8. Manage list style
 */
export default class ContentEdit implements EditorPlugin {
    private settingsOverride?;
    private additionalFeatures?;
    private editor;
    private features;
    /**
     * Create instance of ContentEdit plugin
     * @param settingsOverride An optional feature set to override default feature settings
     * @param additionalFeatures Optional. More features to add
     */
    constructor(settingsOverride?: Partial<ContentEditFeatureSettings> | undefined, additionalFeatures?: GenericContentEditFeature<PluginEvent>[] | undefined);
    /**
     * Get a friendly name of  this plugin
     */
    getName(): string;
    /**
     * Initialize this plugin
     * @param editor The editor instance
     */
    initialize(editor: IEditor): void;
    private disposeFeatures;
    /**
     * Dispose this plugin
     */
    dispose(): void;
}
