import getTargetSizeByPercentage from '../editInfoUtils/getTargetSizeByPercentage';
import { getEditInfoFromImage } from '../editInfoUtils/editInfo';
/**
 * Check if the image is already resized to the given percentage
 * @param image The image to check
 * @param percentage The percentage to check
 * @param maxError Maximum difference of pixels to still be considered the same size
 */
export default function isResizedTo(image, percentage, maxError) {
    if (maxError === void 0) { maxError = 1; }
    var editInfo = getEditInfoFromImage(image);
    //Image selection will sometimes return an image which is currently hidden and wrapped. Use HTML attributes as backup
    var visibleHeight = editInfo.heightPx || image.height;
    var visibleWidth = editInfo.widthPx || image.width;
    if (editInfo) {
        var _a = getTargetSizeByPercentage(editInfo, percentage), width = _a.width, height = _a.height;
        return (Math.abs(width - visibleWidth) < maxError && Math.abs(height - visibleHeight) < maxError);
    }
    return false;
}
//# sourceMappingURL=isResizedTo.js.map