import { clearState } from './utils/clearState';
import { DeleteTableContents } from './features/DeleteTableContents';
import { handleKeyDownEvent } from './keyUtils/handleKeyDownEvent';
import { handleKeyUpEvent } from './keyUtils/handleKeyUpEvent';
import { handleMouseDownEvent } from './mouseUtils/handleMouseDownEvent';
import { handleScrollEvent } from './mouseUtils/handleScrollEvent';
/**
 * TableCellSelectionPlugin help highlight table cells
 */
var TableCellSelection = /** @class */ (function () {
    function TableCellSelection() {
        this.editor = null;
        this.state = {
            firstTable: null,
            lastTarget: null,
            firstTarget: null,
            preventKeyUp: false,
            startedSelection: false,
            tableSelection: false,
            targetTable: null,
            vTable: null,
            mouseMoveDisposer: null,
        };
    }
    /**
     * Get a friendly name of  this plugin
     */
    TableCellSelection.prototype.getName = function () {
        return 'TableCellSelection';
    };
    /**
     * Initialize this plugin. This should only be called from Editor
     * @param editor Editor instance
     */
    TableCellSelection.prototype.initialize = function (editor) {
        this.editor = editor;
        this.editor.addContentEditFeature(DeleteTableContents);
    };
    /**
     * Dispose this plugin
     */
    TableCellSelection.prototype.dispose = function () {
        clearState(this.state, this.editor);
        this.state = null;
        this.editor = null;
    };
    /**
     * Handle events triggered from editor
     * @param event PluginEvent object
     */
    TableCellSelection.prototype.onPluginEvent = function (event) {
        if (this.editor && this.state) {
            switch (event.eventType) {
                case 5 /* MouseDown */:
                    if (!this.state.startedSelection) {
                        handleMouseDownEvent(event, this.state, this.editor);
                    }
                    break;
                case 0 /* KeyDown */:
                    if (!this.state.startedSelection) {
                        handleKeyDownEvent(event, this.state, this.editor);
                    }
                    else {
                        event.rawEvent.preventDefault();
                    }
                    break;
                case 2 /* KeyUp */:
                    if (!this.state.startedSelection) {
                        handleKeyUpEvent(event, this.state, this.editor);
                    }
                    else {
                        event.rawEvent.preventDefault();
                    }
                    break;
                case 14 /* Scroll */:
                    if (this.state.startedSelection) {
                        handleScrollEvent(this.state, this.editor);
                    }
                    break;
                case 20 /* BeforeSetContent */:
                    this.state.firstTable = null;
                    this.state.tableSelection = false;
                    this.editor.select(null);
                    break;
            }
        }
    };
    return TableCellSelection;
}());
export default TableCellSelection;
//# sourceMappingURL=TableCellSelection.js.map