import { safeInstanceOf } from 'roosterjs-editor-dom';
import { TABLE_CELL_SELECTOR } from '../constants';
/**
 * @internal
 * Feature that when Backspace is pressed and there is Table Selection, delete the contents inside of the selection
 */
export var DeleteTableContents = {
    keys: [46 /* DELETE */, 8 /* BACKSPACE */],
    shouldHandleEvent: function (_, editor) {
        var selection = editor.getSelectionRangeEx();
        return selection.type == 1 /* TableSelection */;
    },
    handleEvent: function (_, editor) {
        var selection = editor.getSelectionRangeEx();
        if (selection.type == 1 /* TableSelection */) {
            editor.addUndoSnapshot(function () {
                if (selection.isWholeTableSelected) {
                    selection.table
                        .querySelectorAll(TABLE_CELL_SELECTOR)
                        .forEach(function (td) { return deleteNodeContents(td, editor); });
                }
                else {
                    editor
                        .getSelectedRegions()
                        .forEach(function (region) { return deleteNodeContents(region.rootNode, editor); });
                }
            });
        }
    },
};
function deleteNodeContents(element, editor) {
    if (safeInstanceOf(element, 'HTMLTableCellElement')) {
        var range = new Range();
        range.selectNodeContents(element);
        range.deleteContents();
        element.appendChild(editor.getDocument().createElement('br'));
    }
}
//# sourceMappingURL=DeleteTableContents.js.map